import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export interface RandomizerRNGInterface extends Interface {
    getFunction(nameOrSignature: "callbackGasLimit" | "changeGovernor" | "governor" | "initialize" | "proxiableUUID" | "randomNumbers" | "randomizer" | "randomizerCallback" | "randomizerWithdraw" | "receiveRandomness" | "requestRandomness" | "requesterToID" | "setCallbackGasLimit" | "setRandomizer" | "upgradeToAndCall"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "Initialized" | "Upgraded"): EventFragment;
    encodeFunctionData(functionFragment: "callbackGasLimit", values?: undefined): string;
    encodeFunctionData(functionFragment: "changeGovernor", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "proxiableUUID", values?: undefined): string;
    encodeFunctionData(functionFragment: "randomNumbers", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "randomizer", values?: undefined): string;
    encodeFunctionData(functionFragment: "randomizerCallback", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "randomizerWithdraw", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "receiveRandomness", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "requestRandomness", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "requesterToID", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "setCallbackGasLimit", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRandomizer", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [AddressLike, BytesLike]): string;
    decodeFunctionResult(functionFragment: "callbackGasLimit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "proxiableUUID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomNumbers", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomizer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomizerCallback", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomizerWithdraw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "receiveRandomness", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "requestRandomness", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "requesterToID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCallbackGasLimit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRandomizer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
}
export declare namespace InitializedEvent {
    type InputTuple = [version: BigNumberish];
    type OutputTuple = [version: bigint];
    interface OutputObject {
        version: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace UpgradedEvent {
    type InputTuple = [newImplementation: AddressLike];
    type OutputTuple = [newImplementation: string];
    interface OutputObject {
        newImplementation: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface RandomizerRNG extends BaseContract {
    connect(runner?: ContractRunner | null): RandomizerRNG;
    waitForDeployment(): Promise<this>;
    interface: RandomizerRNGInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    callbackGasLimit: TypedContractMethod<[], [bigint], "view">;
    changeGovernor: TypedContractMethod<[
        _governor: AddressLike
    ], [
        void
    ], "nonpayable">;
    governor: TypedContractMethod<[], [string], "view">;
    initialize: TypedContractMethod<[
        _randomizer: AddressLike,
        _governor: AddressLike
    ], [
        void
    ], "nonpayable">;
    proxiableUUID: TypedContractMethod<[], [string], "view">;
    randomNumbers: TypedContractMethod<[
        requestId: BigNumberish
    ], [
        bigint
    ], "view">;
    randomizer: TypedContractMethod<[], [string], "view">;
    randomizerCallback: TypedContractMethod<[
        _id: BigNumberish,
        _value: BytesLike
    ], [
        void
    ], "nonpayable">;
    randomizerWithdraw: TypedContractMethod<[
        _amount: BigNumberish
    ], [
        void
    ], "nonpayable">;
    receiveRandomness: TypedContractMethod<[
        arg0: BigNumberish
    ], [
        bigint
    ], "view">;
    requestRandomness: TypedContractMethod<[
        arg0: BigNumberish
    ], [
        void
    ], "nonpayable">;
    requesterToID: TypedContractMethod<[
        requester: AddressLike
    ], [
        bigint
    ], "view">;
    setCallbackGasLimit: TypedContractMethod<[
        _callbackGasLimit: BigNumberish
    ], [
        void
    ], "nonpayable">;
    setRandomizer: TypedContractMethod<[
        _randomizer: AddressLike
    ], [
        void
    ], "nonpayable">;
    upgradeToAndCall: TypedContractMethod<[
        newImplementation: AddressLike,
        data: BytesLike
    ], [
        void
    ], "payable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "callbackGasLimit"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "changeGovernor"): TypedContractMethod<[_governor: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "governor"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "initialize"): TypedContractMethod<[
        _randomizer: AddressLike,
        _governor: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "proxiableUUID"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "randomNumbers"): TypedContractMethod<[requestId: BigNumberish], [bigint], "view">;
    getFunction(nameOrSignature: "randomizer"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "randomizerCallback"): TypedContractMethod<[
        _id: BigNumberish,
        _value: BytesLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "randomizerWithdraw"): TypedContractMethod<[_amount: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "receiveRandomness"): TypedContractMethod<[arg0: BigNumberish], [bigint], "view">;
    getFunction(nameOrSignature: "requestRandomness"): TypedContractMethod<[arg0: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "requesterToID"): TypedContractMethod<[requester: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "setCallbackGasLimit"): TypedContractMethod<[
        _callbackGasLimit: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setRandomizer"): TypedContractMethod<[_randomizer: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "upgradeToAndCall"): TypedContractMethod<[
        newImplementation: AddressLike,
        data: BytesLike
    ], [
        void
    ], "payable">;
    getEvent(key: "Initialized"): TypedContractEvent<InitializedEvent.InputTuple, InitializedEvent.OutputTuple, InitializedEvent.OutputObject>;
    getEvent(key: "Upgraded"): TypedContractEvent<UpgradedEvent.InputTuple, UpgradedEvent.OutputTuple, UpgradedEvent.OutputObject>;
    filters: {
        "Initialized(uint64)": TypedContractEvent<InitializedEvent.InputTuple, InitializedEvent.OutputTuple, InitializedEvent.OutputObject>;
        Initialized: TypedContractEvent<InitializedEvent.InputTuple, InitializedEvent.OutputTuple, InitializedEvent.OutputObject>;
        "Upgraded(address)": TypedContractEvent<UpgradedEvent.InputTuple, UpgradedEvent.OutputTuple, UpgradedEvent.OutputObject>;
        Upgraded: TypedContractEvent<UpgradedEvent.InputTuple, UpgradedEvent.OutputTuple, UpgradedEvent.OutputObject>;
    };
}
